@@ -1,14 +1,19 @@
-from tqdm import *
+from tqdm import trange
 from time import sleep
 import time
 from random import randint,choice
 from os import system,urandom
 from termcolor import colored
 import f61d.LOGO as LOGO
-from f61d.__version__ import *
+#from f61d.__version__ import *
 from math import ceil
 
-print(colored(LOGO.randlogo(),choice(['red','yellow','green'])))
+VERSION = (0,2,5)
+VERSION = '.'.join(map(str, VERSION))
+
+
+
+print(colored(LOGO.randlogo()+' v'+VERSION+'\n\n',choice(['red','yellow','green'])))
 print(colored("Welcome to F61D. Use Help() for help.",'green'))
 
 help_cont = {}
@@ -17,26 +22,29 @@ help_cont[1] = 'fuckStar : One Button to fuck Satellite'
 help_cont[9] = 'lifeGame : Play the Life Game'
 help_cont[3] = 'paint    : Draw a Bing Dwen Dwen'
 help_cont[4] = 'b64tofile: Decode base64 to a file'
-help_cont[5] = 'prove    : Prove your self. Only support:\n                  sha256(XXXX + abcdef) = aaabbb...'
+help_cont[5] = 'prove    : Prove your self. Only support:\n\t\t  sha256(XXXX + abcdef) = aaabbb...'
 help_cont[6] = 'Nim      : An interesting turtle game.'
 help_cont[7] = 'getLogo  : Print the "F61D" LOGO.'
 help_cont[8] = 'yinyang  : Draw the TaiJi.'
 help_cont[2] = 'timeit   : Take a time for your function.\n\t\t  Just add a '+colored('@timeit','cyan')+colored(' before you define the function','green')
 
+
+
 def Help(page=1,lines = 5):
     if type(page) != int or type(lines) != int:
+        Help(1,10000)
         return print('Please input interger.')
     if page == 0:
         return Help(1,10000)
     maxPage = ceil(len(help_cont)/lines)#int((0.5+len(help_cont))/lines)+1
     if (page - 1) * lines >= len(help_cont):
-        print(f'Page Error, check the number : [{1},{maxPage}]')
+        print(f'Page Error, check the number : [1,{maxPage}]')
         return
     print(colored(f"{'=-'*14}= ",'yellow')+"H E L P"+colored(f" {'=-'*14}=\n",'yellow'))
     for i in range(lines):
         try:
             n = i+lines*(page-1)
-            ll = colored(f"{help_cont[n]}",'green')
+            ll = colored(help_cont[n],'green')
             print(f'   {n} - '+ll)
         except:break
     print('\n'+colored(f"{'=-'*14}= ",'yellow')+f"page({page}/{maxPage})"+colored(f" {'=-'*14}=",'yellow'))
@@ -44,6 +52,9 @@ def Help(page=1,lines = 5):
 
 
 def fuckStar():
+    '''
+一键日卫星
+'''
     print(' - 欢迎使用一键日卫星功能')
     print(' - 请输入要日的卫星编号(可在官网查询):',end='')
     num = input()
